# `dustpan`

[![pypi version](https://img.shields.io/pypi/v/dustpan.svg?style=flat)](https://pypi.org/pypi/dustpan/)
[![downloads](https://pepy.tech/badge/dustpan)](https://pepy.tech/project/dustpan)
[![build status](https://github.com/dawsonbooth/dustpan/workflows/build/badge.svg)](https://github.com/dawsonbooth/dustpan/actions?workflow=build)
[![python versions](https://img.shields.io/pypi/pyversions/dustpan.svg?style=flat)](https://pypi.org/pypi/dustpan/)
[![format](https://img.shields.io/pypi/format/dustpan.svg?style=flat)](https://pypi.org/pypi/dustpan/)
[![license](https://img.shields.io/pypi/l/dustpan.svg?style=flat)](https://github.com/dawsonbooth/dustpan/blob/master/LICENSE)

## Description

This is a short or long textual description of the package.

## Installation

With [Python](https://www.python.org/downloads/) installed, simply run the following command to add the package to your project.

```bash
python -m pip install dustpan
```

## Usage

The following is an example usage of the package:

```python
from foo import bar

print("Ok here we go")

try:
    bar()
except:
    print("Ah good effort")
```

Some info about calling the program.

```bash
python whatever.py > out.txt
```

Then some output (console or file whatever)

```txt
Output here I guess
```

Feel free to [check out the docs](https://dawsonbooth.github.io/dustpan/) for more information.

## License

This software is released under the terms of [MIT license](LICENSE).
